Module Name:    src
Committed By:   andvar
Date:           Wed Feb 16 22:00:57 UTC 2022

Modified Files:
        src/sbin/nvmectl: identify.c
        src/sys/arch/aarch64/aarch64: pmap.c
        src/sys/arch/arm/samsung: exynos4_reg.h
        src/sys/dev/ata: satareg.h
        src/sys/dev/ic: mvsatareg.h
        src/sys/dev/marvell: if_mvxpe.c if_mvxpevar.h
        src/sys/dev/pci: if_sip.c
        src/sys/dev/raidframe: rf_evenodd_dagfuncs.c
        src/sys/dev/usb: if_atureg.h
        src/sys/fs/nilfs: nilfs_fs.h
        src/sys/fs/udf: udf_vnops.c
        src/sys/net80211: ieee80211_node.h
        src/sys/netinet: ip_reass.c sctp_timer.c

Log Message:
fix various typos, mainly in comments.


To generate a diff of this commit:
cvs rdiff -u -r1.7 -r1.8 src/sbin/nvmectl/identify.c
cvs rdiff -u -r1.127 -r1.128 src/sys/arch/aarch64/aarch64/pmap.c
cvs rdiff -u -r1.15 -r1.16 src/sys/arch/arm/samsung/exynos4_reg.h
cvs rdiff -u -r1.6 -r1.7 src/sys/dev/ata/satareg.h
cvs rdiff -u -r1.4 -r1.5 src/sys/dev/ic/mvsatareg.h
cvs rdiff -u -r1.38 -r1.39 src/sys/dev/marvell/if_mvxpe.c
cvs rdiff -u -r1.6 -r1.7 src/sys/dev/marvell/if_mvxpevar.h
cvs rdiff -u -r1.184 -r1.185 src/sys/dev/pci/if_sip.c
cvs rdiff -u -r1.24 -r1.25 src/sys/dev/raidframe/rf_evenodd_dagfuncs.c
cvs rdiff -u -r1.12 -r1.13 src/sys/dev/usb/if_atureg.h
cvs rdiff -u -r1.3 -r1.4 src/sys/fs/nilfs/nilfs_fs.h
cvs rdiff -u -r1.118 -r1.119 src/sys/fs/udf/udf_vnops.c
cvs rdiff -u -r1.30 -r1.31 src/sys/net80211/ieee80211_node.h
cvs rdiff -u -r1.21 -r1.22 src/sys/netinet/ip_reass.c
cvs rdiff -u -r1.5 -r1.6 src/sys/netinet/sctp_timer.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sbin/nvmectl/identify.c
diff -u src/sbin/nvmectl/identify.c:1.7 src/sbin/nvmectl/identify.c:1.8
--- src/sbin/nvmectl/identify.c:1.7	Sun Sep 27 16:45:21 2020
+++ src/sbin/nvmectl/identify.c	Wed Feb 16 22:00:55 2022
@@ -1,4 +1,4 @@
-/*	$NetBSD: identify.c,v 1.7 2020/09/27 16:45:21 jdolecek Exp $	*/
+/*	$NetBSD: identify.c,v 1.8 2022/02/16 22:00:55 andvar Exp $	*/
 
 /*-
  * SPDX-License-Identifier: BSD-2-Clause-FreeBSD
@@ -30,7 +30,7 @@
 
 #include <sys/cdefs.h>
 #ifndef lint
-__RCSID("$NetBSD: identify.c,v 1.7 2020/09/27 16:45:21 jdolecek Exp $");
+__RCSID("$NetBSD: identify.c,v 1.8 2022/02/16 22:00:55 andvar Exp $");
 #if 0
 __FBSDID("$FreeBSD: head/sbin/nvmecontrol/identify.c 329824 2018-02-22 13:32:31Z wma $");
 #endif
@@ -88,7 +88,7 @@ print_controller(struct nvm_identify_con
 	printf("Firmware Activate/Download:  %s\n",
 		(cdata->oacs & NVME_ID_CTRLR_OACS_FW) ?
 		"Supported" : "Not Supported");
-	printf("Namespace Managment:         %s\n",
+	printf("Namespace Management:         %s\n",
 		(cdata->oacs & NVME_ID_CTRLR_OACS_NS) ?
 		"Supported" : "Not Supported");
 	printf("Abort Command Limit:         %d\n", cdata->acl+1);

Index: src/sys/arch/aarch64/aarch64/pmap.c
diff -u src/sys/arch/aarch64/aarch64/pmap.c:1.127 src/sys/arch/aarch64/aarch64/pmap.c:1.128
--- src/sys/arch/aarch64/aarch64/pmap.c:1.127	Mon Jan 31 09:16:09 2022
+++ src/sys/arch/aarch64/aarch64/pmap.c	Wed Feb 16 22:00:55 2022
@@ -1,4 +1,4 @@
-/*	$NetBSD: pmap.c,v 1.127 2022/01/31 09:16:09 ryo Exp $	*/
+/*	$NetBSD: pmap.c,v 1.128 2022/02/16 22:00:55 andvar Exp $	*/
 
 /*
  * Copyright (c) 2017 Ryo Shimizu <r...@nerv.org>
@@ -27,7 +27,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: pmap.c,v 1.127 2022/01/31 09:16:09 ryo Exp $");
+__KERNEL_RCSID(0, "$NetBSD: pmap.c,v 1.128 2022/02/16 22:00:55 andvar Exp $");
 
 #include "opt_arm_debug.h"
 #include "opt_cpuoptions.h"
@@ -1620,7 +1620,7 @@ _pmap_pdp_addref(struct pmap *pm, paddr_
 }
 
 /*
- * decrement reference counter of the page descriptr page.
+ * decrement reference counter of the page descriptor page.
  * if reference counter is 1(=empty), pages will be freed, and return true.
  * otherwise return false.
  * kernel page, or L0 page descriptor page will be never freed.

Index: src/sys/arch/arm/samsung/exynos4_reg.h
diff -u src/sys/arch/arm/samsung/exynos4_reg.h:1.15 src/sys/arch/arm/samsung/exynos4_reg.h:1.16
--- src/sys/arch/arm/samsung/exynos4_reg.h:1.15	Sun Aug 19 07:27:33 2018
+++ src/sys/arch/arm/samsung/exynos4_reg.h	Wed Feb 16 22:00:55 2022
@@ -1,4 +1,4 @@
-/*	$NetBSD: exynos4_reg.h,v 1.15 2018/08/19 07:27:33 skrll Exp $	*/
+/*	$NetBSD: exynos4_reg.h,v 1.16 2022/02/16 22:00:55 andvar Exp $	*/
 
 /*-
  * Copyright (c) 2014 The NetBSD Foundation, Inc.
@@ -127,7 +127,7 @@
 #define EXYNOS4_RTC_OFFSET			0x00070000	/* Real Time Clock */
 #define EXYNOS4_KEYIF_OFFSET			0x000A0000	/* Keypad interface */
 #define EXYNOS4_HDMI_CEC_OFFSET			0x000B0000	/* HDMI Consumer Electronic Control */
-#define EXYNOS4_TMU_OFFSET			0x000C0000	/* Thermal Managment */
+#define EXYNOS4_TMU_OFFSET			0x000C0000	/* Thermal Management */
 #define EXYNOS4_SECKEY_OFFSET			0x00100000	/* XXX unknown XXX */
 #define EXYNOS4_TZPC0_OFFSET			0x00110000	/* ARM Trusted Zone Protection Controller */
 #define EXYNOS4_TZPC1_OFFSET			0x00120000

Index: src/sys/dev/ata/satareg.h
diff -u src/sys/dev/ata/satareg.h:1.6 src/sys/dev/ata/satareg.h:1.7
--- src/sys/dev/ata/satareg.h:1.6	Sun Dec 27 15:15:45 2020
+++ src/sys/dev/ata/satareg.h	Wed Feb 16 22:00:55 2022
@@ -1,4 +1,4 @@
-/*	$NetBSD: satareg.h,v 1.6 2020/12/27 15:15:45 jmcneill Exp $	*/
+/*	$NetBSD: satareg.h,v 1.7 2022/02/16 22:00:55 andvar Exp $	*/
 
 /*-
  * Copyright (c) 2003 The NetBSD Foundation, Inc.
@@ -69,7 +69,7 @@
 #define	SStatus_SPD_mask	(0xf << 4)
 #define	SStatus_SPD_shift	4
 	/*
-	 * The IPM value indicates the current interface power managemnt
+	 * The IPM value indicates the current interface power management
 	 * state.
 	 */
 #define	SStatus_IPM_NODEV	(0x0 << 8)	/* no device connected */

Index: src/sys/dev/ic/mvsatareg.h
diff -u src/sys/dev/ic/mvsatareg.h:1.4 src/sys/dev/ic/mvsatareg.h:1.5
--- src/sys/dev/ic/mvsatareg.h:1.4	Sat Oct  7 16:05:32 2017
+++ src/sys/dev/ic/mvsatareg.h	Wed Feb 16 22:00:55 2022
@@ -1,4 +1,4 @@
-/*	$NetBSD: mvsatareg.h,v 1.4 2017/10/07 16:05:32 jdolecek Exp $	*/
+/*	$NetBSD: mvsatareg.h,v 1.5 2022/02/16 22:00:55 andvar Exp $	*/
 /*
  * Copyright (c) 2008 KIYOHARA Takashi
  * All rights reserved.
@@ -250,15 +250,15 @@
 
 /* EDMA Command Request Block (CRQB) Data */
 struct crqb {
-	uint32_t cprdbl;	/* cPRD Desriptor Table Base Low Address */
-	uint32_t cprdbh;	/* cPRD Desriptor Table Base High Address */
+	uint32_t cprdbl;	/* cPRD Descriptor Table Base Low Address */
+	uint32_t cprdbh;	/* cPRD Descriptor Table Base High Address */
 	uint16_t ctrlflg;	/* Control Flags */
 	uint16_t atacommand[11];
 } __packed __aligned(8);
 
 struct crqb_gen2e {
-	uint32_t cprdbl;	/* cPRD Desriptor Table Base Low Address */
-	uint32_t cprdbh;	/* cPRD Desriptor Table Base High Address */
+	uint32_t cprdbl;	/* cPRD Descriptor Table Base Low Address */
+	uint32_t cprdbh;	/* cPRD Descriptor Table Base High Address */
 	uint32_t ctrlflg;	/* Control Flags */
 	uint32_t drbc;		/* Data Region Byte Count */
 	uint8_t atacommand[16];

Index: src/sys/dev/marvell/if_mvxpe.c
diff -u src/sys/dev/marvell/if_mvxpe.c:1.38 src/sys/dev/marvell/if_mvxpe.c:1.39
--- src/sys/dev/marvell/if_mvxpe.c:1.38	Sat Feb 12 03:24:35 2022
+++ src/sys/dev/marvell/if_mvxpe.c	Wed Feb 16 22:00:56 2022
@@ -1,4 +1,4 @@
-/*	$NetBSD: if_mvxpe.c,v 1.38 2022/02/12 03:24:35 riastradh Exp $	*/
+/*	$NetBSD: if_mvxpe.c,v 1.39 2022/02/16 22:00:56 andvar Exp $	*/
 /*
  * Copyright (c) 2015 Internet Initiative Japan Inc.
  * All rights reserved.
@@ -25,7 +25,7 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: if_mvxpe.c,v 1.38 2022/02/12 03:24:35 riastradh Exp $");
+__KERNEL_RCSID(0, "$NetBSD: if_mvxpe.c,v 1.39 2022/02/16 22:00:56 andvar Exp $");
 
 #include "opt_multiprocessor.h"
 
@@ -2611,7 +2611,7 @@ mvxpe_rx_queue_add(struct mvxpe_softc *s
 		return ENOBUFS;
 	}
 
-	/* Add the packet to descritor */
+	/* Add the packet to descriptor */
 	KASSERT(MVXPE_RX_PKTBUF(sc, q, rx->rx_cpu) == NULL);
 	MVXPE_RX_PKTBUF(sc, q, rx->rx_cpu) = chunk;
 	mvxpbm_dmamap_sync(chunk, BM_SYNC_ALL, BUS_DMASYNC_PREREAD);

Index: src/sys/dev/marvell/if_mvxpevar.h
diff -u src/sys/dev/marvell/if_mvxpevar.h:1.6 src/sys/dev/marvell/if_mvxpevar.h:1.7
--- src/sys/dev/marvell/if_mvxpevar.h:1.6	Sun Dec  5 02:47:01 2021
+++ src/sys/dev/marvell/if_mvxpevar.h	Wed Feb 16 22:00:56 2022
@@ -1,4 +1,4 @@
-/*	$NetBSD: if_mvxpevar.h,v 1.6 2021/12/05 02:47:01 msaitoh Exp $	*/
+/*	$NetBSD: if_mvxpevar.h,v 1.7 2022/02/16 22:00:56 andvar Exp $	*/
 /*
  * Copyright (c) 2015 Internet Initiative Japan Inc.
  * All rights reserved.
@@ -117,7 +117,7 @@ struct mvxpe_rx_ring {
 	struct mvxpe_rx_desc		*rx_descriptors;
 	bus_dmamap_t			rx_descriptors_map;
 
-	/* Managment entries for each of descritors */
+	/* Management entries for each of descriptors */
 	struct mvxpe_rx_handle {
 		struct mvxpe_rx_desc	*rxdesc_va;
 		off_t			rxdesc_off; /* from rx_descriptors[0] */
@@ -143,7 +143,7 @@ struct mvxpe_tx_ring {
 	struct mvxpe_tx_desc		*tx_descriptors;
 	bus_dmamap_t			tx_descriptors_map;
 
-	/* Managment entries for each of descritors */
+	/* Management entries for each of descriptors */
 	struct mvxpe_tx_handle {
 		struct mvxpe_tx_desc	*txdesc_va;
 		off_t			txdesc_off; /* from tx_descriptors[0] */

Index: src/sys/dev/pci/if_sip.c
diff -u src/sys/dev/pci/if_sip.c:1.184 src/sys/dev/pci/if_sip.c:1.185
--- src/sys/dev/pci/if_sip.c:1.184	Fri Dec 31 14:25:23 2021
+++ src/sys/dev/pci/if_sip.c	Wed Feb 16 22:00:56 2022
@@ -1,4 +1,4 @@
-/*	$NetBSD: if_sip.c,v 1.184 2021/12/31 14:25:23 riastradh Exp $	*/
+/*	$NetBSD: if_sip.c,v 1.185 2022/02/16 22:00:56 andvar Exp $	*/
 
 /*-
  * Copyright (c) 2001, 2002 The NetBSD Foundation, Inc.
@@ -73,7 +73,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: if_sip.c,v 1.184 2021/12/31 14:25:23 riastradh Exp $");
+__KERNEL_RCSID(0, "$NetBSD: if_sip.c,v 1.185 2022/02/16 22:00:56 andvar Exp $");
 
 #include <sys/param.h>
 #include <sys/systm.h>
@@ -1702,7 +1702,7 @@ sipcom_start(struct ifnet *ifp)
 		    BUS_DMASYNC_PREREAD | BUS_DMASYNC_PREWRITE);
 
 		/*
-		 * The entire packet is set up.  Give the first descrptor
+		 * The entire packet is set up.  Give the first descriptor
 		 * to the chip now.
 		 */
 		sc->sc_txdescs[sc->sc_txnext].sipd_words[sc->sc_cmdsts_idx] |=

Index: src/sys/dev/usb/if_atureg.h
diff -u src/sys/dev/usb/if_atureg.h:1.12 src/sys/dev/usb/if_atureg.h:1.13
--- src/sys/dev/usb/if_atureg.h:1.12	Sun Mar 15 23:04:50 2020
+++ src/sys/dev/usb/if_atureg.h	Wed Feb 16 22:00:56 2022
@@ -1,4 +1,4 @@
-/*	$NetBSD: if_atureg.h,v 1.12 2020/03/15 23:04:50 thorpej Exp $ */
+/*	$NetBSD: if_atureg.h,v 1.13 2022/02/16 22:00:56 andvar Exp $ */
 /*	$OpenBSD: if_atureg.h,v 1.21 2004/12/23 13:19:38 dlg Exp $ */
 /*
  * Copyright (c) 2003
@@ -375,7 +375,7 @@ struct atu_fw {
 } UPACKED;
 
 /*
- * The header the AT76c503 puts in front of RX packets (for both managment &
+ * The header the AT76c503 puts in front of RX packets (for both management &
  * data)
  */
 struct atu_rx_hdr {

Index: src/sys/fs/nilfs/nilfs_fs.h
diff -u src/sys/fs/nilfs/nilfs_fs.h:1.3 src/sys/fs/nilfs/nilfs_fs.h:1.4
--- src/sys/fs/nilfs/nilfs_fs.h:1.3	Sat Dec  1 11:41:49 2012
+++ src/sys/fs/nilfs/nilfs_fs.h	Wed Feb 16 22:00:56 2022
@@ -1,4 +1,4 @@
-/* $NetBSD: nilfs_fs.h,v 1.3 2012/12/01 11:41:49 mbalmer Exp $ */
+/* $NetBSD: nilfs_fs.h,v 1.4 2022/02/16 22:00:56 andvar Exp $ */
 
 /*
  * Copyright (c) 2008, 2009 Reinoud Zandijk
@@ -447,7 +447,7 @@ struct nilfs_segment_summary {
 /*
  * Structure of DAT/inode file.
  *
- * A DAT file is devided into groups. The maximum number of groups is the
+ * A DAT file is divided into groups. The maximum number of groups is the
  * number of block group descriptors that fit into one block; this descriptor
  * only gives the number of free entries in the associated group.
  *

Index: src/sys/fs/udf/udf_vnops.c
diff -u src/sys/fs/udf/udf_vnops.c:1.118 src/sys/fs/udf/udf_vnops.c:1.119
--- src/sys/fs/udf/udf_vnops.c:1.118	Sun Feb  6 20:20:19 2022
+++ src/sys/fs/udf/udf_vnops.c	Wed Feb 16 22:00:56 2022
@@ -1,4 +1,4 @@
-/* $NetBSD: udf_vnops.c,v 1.118 2022/02/06 20:20:19 andvar Exp $ */
+/* $NetBSD: udf_vnops.c,v 1.119 2022/02/16 22:00:56 andvar Exp $ */
 
 /*
  * Copyright (c) 2006, 2008 Reinoud Zandijk
@@ -32,7 +32,7 @@
 
 #include <sys/cdefs.h>
 #ifndef lint
-__KERNEL_RCSID(0, "$NetBSD: udf_vnops.c,v 1.118 2022/02/06 20:20:19 andvar Exp $");
+__KERNEL_RCSID(0, "$NetBSD: udf_vnops.c,v 1.119 2022/02/16 22:00:56 andvar Exp $");
 #endif /* not lint */
 
 
@@ -104,7 +104,7 @@ udf_inactive(void *v)
 
 	if ((refcnt == 0) && (vp->v_vflag & VV_SYSTEM)) {
 		DPRINTF(VOLUMES, ("UDF_INACTIVE deleting VV_SYSTEM\n"));
-		/* system nodes are not writen out on inactive, so flush */
+		/* system nodes are not written out on inactive, so flush */
 		udf_node->i_flags = 0;
 	}
 

Index: src/sys/net80211/ieee80211_node.h
diff -u src/sys/net80211/ieee80211_node.h:1.30 src/sys/net80211/ieee80211_node.h:1.31
--- src/sys/net80211/ieee80211_node.h:1.30	Thu Apr 19 21:50:10 2018
+++ src/sys/net80211/ieee80211_node.h	Wed Feb 16 22:00:56 2022
@@ -1,4 +1,4 @@
-/*	$NetBSD: ieee80211_node.h,v 1.30 2018/04/19 21:50:10 christos Exp $	*/
+/*	$NetBSD: ieee80211_node.h,v 1.31 2022/02/16 22:00:56 andvar Exp $	*/
 /*-
  * Copyright (c) 2001 Atsushi Onoe
  * Copyright (c) 2002-2005 Sam Leffler, Errno Consulting
@@ -76,7 +76,7 @@ struct ieee80211_rsnparms {
 	u_int8_t	rsn_ucastcipherset;	/* unicast cipher set */
 	u_int8_t	rsn_ucastcipher;	/* selected unicast cipher */
 	u_int8_t	rsn_ucastkeylen;	/* unicast key length */
-	u_int8_t	rsn_keymgmtset;		/* key mangement algorithms */
+	u_int8_t	rsn_keymgmtset;		/* key management algorithms */
 	u_int8_t	rsn_keymgmt;		/* selected key mgmt algo */
 	u_int16_t	rsn_caps;		/* capabilities */
 };

Index: src/sys/netinet/ip_reass.c
diff -u src/sys/netinet/ip_reass.c:1.21 src/sys/netinet/ip_reass.c:1.22
--- src/sys/netinet/ip_reass.c:1.21	Fri Oct 12 05:41:18 2018
+++ src/sys/netinet/ip_reass.c	Wed Feb 16 22:00:56 2022
@@ -1,4 +1,4 @@
-/*	$NetBSD: ip_reass.c,v 1.21 2018/10/12 05:41:18 maxv Exp $	*/
+/*	$NetBSD: ip_reass.c,v 1.22 2022/02/16 22:00:56 andvar Exp $	*/
 
 /*
  * Copyright (c) 1982, 1986, 1988, 1993
@@ -35,7 +35,7 @@
  * IP reassembly.
  *
  * Additive-Increase/Multiplicative-Decrease (AIMD) strategy for IP
- * reassembly queue buffer managment.
+ * reassembly queue buffer management.
  *
  * We keep a count of total IP fragments (NB: not fragmented packets),
  * awaiting reassembly (ip_nfrags) and a limit (ip_maxfrags) on fragments.
@@ -46,7 +46,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: ip_reass.c,v 1.21 2018/10/12 05:41:18 maxv Exp $");
+__KERNEL_RCSID(0, "$NetBSD: ip_reass.c,v 1.22 2022/02/16 22:00:56 andvar Exp $");
 
 #include <sys/param.h>
 #include <sys/types.h>

Index: src/sys/netinet/sctp_timer.c
diff -u src/sys/netinet/sctp_timer.c:1.5 src/sys/netinet/sctp_timer.c:1.6
--- src/sys/netinet/sctp_timer.c:1.5	Tue May  1 07:21:39 2018
+++ src/sys/netinet/sctp_timer.c	Wed Feb 16 22:00:56 2022
@@ -1,5 +1,5 @@
 /*	$KAME: sctp_timer.c,v 1.30 2005/06/16 18:29:25 jinmei Exp $	*/
-/*	$NetBSD: sctp_timer.c,v 1.5 2018/05/01 07:21:39 maxv Exp $	*/
+/*	$NetBSD: sctp_timer.c,v 1.6 2022/02/16 22:00:56 andvar Exp $	*/
 
 /*
  * Copyright (C) 2002, 2003, 2004 Cisco Systems Inc,
@@ -30,7 +30,7 @@
  * SUCH DAMAGE.
  */
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: sctp_timer.c,v 1.5 2018/05/01 07:21:39 maxv Exp $");
+__KERNEL_RCSID(0, "$NetBSD: sctp_timer.c,v 1.6 2022/02/16 22:00:56 andvar Exp $");
 
 #ifdef _KERNEL_OPT
 #include "opt_inet.h"
@@ -1069,7 +1069,7 @@ int sctp_asconf_timer(struct sctp_inpcb 
 		}
 
 		/* PETER? FIX? How will the following code ever run? If
-		 * the max_send_times is hit, threshold managment will
+		 * the max_send_times is hit, threshold management will
 		 * blow away the association?
 		 */
 		if (asconf->snd_count > stcb->asoc.max_send_times) {
@@ -1137,7 +1137,7 @@ sctp_shutdown_timer(struct sctp_inpcb *i
     struct sctp_nets *net)
 {
 	struct sctp_nets *alt;
-	/* first threshold managment */
+	/* first threshold management */
 	if (sctp_threshold_management(inp, stcb, net, stcb->asoc.max_send_times)) {
 		/* Assoc is over */
 		return (1);
@@ -1171,7 +1171,7 @@ int sctp_shutdownack_timer(struct sctp_i
     struct sctp_nets *net)
 {
 	struct sctp_nets *alt;
-	/* first threshold managment */
+	/* first threshold management */
 	if (sctp_threshold_management(inp, stcb, net, stcb->asoc.max_send_times)) {
 		/* Assoc is over */
 		return (1);
@@ -1261,7 +1261,7 @@ sctp_heartbeat_timer(struct sctp_inpcb *
 	    (TAILQ_EMPTY(&stcb->asoc.sent_queue))) {
 		sctp_audit_stream_queues_for_size(inp, stcb);
 	}
-	/* Send a new HB, this will do threshold managment, pick a new dest */
+	/* Send a new HB, this will do threshold management, pick a new dest */
 	if (sctp_send_hb(stcb, 0, NULL) < 0) {
 		return (1);
 	}

Reply via email to
Index: src/sys/dev/raidframe/rf_evenodd_dagfuncs.c
diff -u src/sys/dev/raidframe/rf_evenodd_dagfuncs.c:1.24 src/sys/dev/raidframe/rf_evenodd_dagfuncs.c:1.25
--- src/sys/dev/raidframe/rf_evenodd_dagfuncs.c:1.24	Thu Oct 10 03:43:59 2019
+++ src/sys/dev/raidframe/rf_evenodd_dagfuncs.c	Wed Feb 16 22:00:56 2022
@@ -1,4 +1,4 @@
-/*	$NetBSD: rf_evenodd_dagfuncs.c,v 1.24 2019/10/10 03:43:59 christos Exp $	*/
+/*	$NetBSD: rf_evenodd_dagfuncs.c,v 1.25 2022/02/16 22:00:56 andvar Exp $	*/
 /*
  * Copyright (c) 1995 Carnegie-Mellon University.
  * All rights reserved.
@@ -31,7 +31,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: rf_evenodd_dagfuncs.c,v 1.24 2019/10/10 03:43:59 christos Exp $");
+__KERNEL_RCSID(0, "$NetBSD: rf_evenodd_dagfuncs.c,v 1.25 2022/02/16 22:00:56 andvar Exp $");
 
 #include "rf_archs.h"
 
@@ -79,7 +79,7 @@ rf_RegularPEFunc(RF_DagNode_t *node)
  *  be used. The previous case is when write access at least sectors of full stripe unit.
  *  The later function is used when the write access two stripe units but with total sectors
  *  less than sectors per SU. In this case, the access of parity and 'E' are shown as disconnected
- *  areas in their stripe unit and  parity write and 'E' write are both devided into two distinct
+ *  areas in their stripe unit and  parity write and 'E' write are both divided into two distinct
  *  writes( totally four). This simple old-new write and regular old-new write happen as in RAID-5
  ************************************************************************************************/
 
@@ -168,8 +168,8 @@ rf_SimpleONEFunc(RF_DagNode_t *node)
 														 * writeDataNodes */
 		/* bxor to buffer of readDataNodes */
 		retcode = rf_bxor(node->params[5].p, node->params[1].p, length);
 		/* find out the corresponding colume in encoding matrix for
 		 * write colume to be encoded into redundant disk 'E' */
 		scol = rf_EUCol(layoutPtr, pda->raidAddress);
 		srcbuf = node->params[1].p;
 		destbuf = node->params[3].p;
@@ -233,10 +233,10 @@ rf_RegularEFunc(RF_DagNode_t *node)
  *     one stripe unit is not allowed so that the write can be dealt with like a
  *     large write.
  *  The following function is based on these assumptions. So except in the second case,
- *  it looks the same as a large write encodeing function. But this is not exactly the
+ *  it looks the same as a large write encoding function. But this is not exactly the
  *  normal way for doing a degraded write, since raidframe have to break cases of access
  *  other than the above two into smaller accesses. We may have to change
- *  DegrESubroutin in the future.
+ *  DegrESubroutine in the future.
  *******************************************************************************************/
 void
 rf_DegrESubroutine(RF_DagNode_t *node, char *ebuf)
@@ -297,10 +297,10 @@ rf_e_EncOneSect(
 				 * be Xored into all EUs in a dest sector */
 	int     numRowInEncMatix = (RF_EO_MATRIX_DIM) - 1;
 	RF_RowCol_t j, indexInDest,	/* row index of an encoding unit in
 					 * the destination colume of encoding
 					 * matrix */
 	        indexInSrc;	/* row index of an encoding unit in the source
 				 * colume used for recovery */
 	int     bytesPerEU = bytesPerSector / numRowInEncMatix;
 
 #if RF_EO_MATRIX_DIM > 17
@@ -406,7 +406,7 @@ rf_RecoveryEFunc(RF_DagNode_t *node)
 			if (node->params[i + 1].p != node->results[0]) {
 				pda = (RF_PhysDiskAddr_t *) node->params[i].p;
 				if (i == node->numParams - 4)
-					scol = RF_EO_MATRIX_DIM - 2;	/* the colume of
+					scol = RF_EO_MATRIX_DIM - 2;	/* the column of
 									 * redundant E */
 				else
 					scol = rf_EUCol(layoutPtr, pda->raidAddress);
@@ -481,7 +481,7 @@ rf_doubleEOdecode(
 	RF_ASSERT(*((long *) dest[1]) == 0);
 	RF_ASSERT(*P == 0);
 	/* calculate the 'P' parameter, which, not parity, is the Xor of all
-	 * elements in the last two column, ie. 'E' and 'parity' colume, see
+	 * elements in the last two columns, ie. 'E' and 'parity' columns, see
 	 * the Ref. paper by Blaum, et al 1993  */
 	for (i = 0; i < numRowInEncMatix; i++)
 		for (k = 0; k < longsPerEU; k++) {
@@ -527,7 +527,7 @@ rf_doubleEOdecode(
 		dest_smaller_current = dest_smaller + row * longsPerEU;
 #endif
 		/**    Do the diagonal recovery. Initially, temp[k] = (failed 1),
-		       which is the failed data in the colume which has smaller col index. **/
+		       which is the failed data in the column which has smaller col index. **/
 		/* step 1:  ^(SUM of nonfailed in-diagonal A(rrdrow,0..m-3))         */
 		for (j = 0; j < numDataCol; j++) {
 			if (j == f1 || j == f2)
@@ -545,7 +545,7 @@ rf_doubleEOdecode(
 #endif
 			}
 		}
-		/* step 2:  ^E(erow,m-2), If erow is at the buttom row, don't
+		/* step 2:  ^E(erow,m-2), If erow is at the bottom row, don't
 		 * Xor into it  E(erow,m-2) = (principle diagonal) ^ (failed
 		 * 1) ^ (failed 2) ^ ( SUM of nonfailed in-diagonal
 		 * A(rrdrow,0..m-3) ) After this step, temp[k] = (principle
@@ -582,7 +582,7 @@ rf_doubleEOdecode(
 
 		/**          THE FOLLOWING DO THE HORIZONTAL XOR                **/
 		/* step 1:  ^(SUM of A(row,0..m-3)), ie. all nonfailed data
-		 * columes    */
+		 * columns    */
 		for (j = 0; j < numDataCol; j++) {
 			if (j == f1 || j == f2)
 				continue;
@@ -623,7 +623,7 @@ rf_doubleEOdecode(
 
 
 /***************************************************************************************
-* 	This function is called by double degragded read
+* 	This function is called by double degraded read
 * 	EO_200_CreateReadDAG
 *
 ***************************************************************************************/
@@ -685,7 +685,7 @@ rf_EvenOddDoubleRecoveryFunc(RF_DagNode_
 	/*
             the followings have three goals:
             1. determine the startSector to begin decoding and endSector to end decoding.
-            2. determine the colume numbers of the two failed disks.
+            2. determine the column numbers of the two failed disks.
             3. determine the offset and end offset of the access within each failed stripe unit.
          */
 	if (nresults == 1) {
@@ -702,7 +702,7 @@ rf_EvenOddDoubleRecoveryFunc(RF_DagNode_
 		/* find out the column of failed disk being accessed */
 		fcol[0] = rf_EUCol(layoutPtr, pda->raidAddress);
 
 		/* find out the other failed colume not accessed */
 		sosAddr = rf_RaidAddressOfPrevStripeBoundary(layoutPtr, asmap->raidAddress);
 		for (i = 0; i < numDataCol; i++) {
 			npda.raidAddress = sosAddr + (i * secPerSU);
@@ -720,7 +720,7 @@ rf_EvenOddDoubleRecoveryFunc(RF_DagNode_
 		memset(pda0->bufPtr, 0, bytesPerSector * pda0->numSector);
 		pda1 = node->results[1];
 		memset(pda1->bufPtr, 0, bytesPerSector * pda1->numSector);
 		/* determine the failed colume numbers of the two failed
 		 * disks. */
 		fcol[0] = rf_EUCol(layoutPtr, pda0->raidAddress);
 		fcol[1] = rf_EUCol(layoutPtr, pda1->raidAddress);
@@ -737,7 +737,7 @@ rf_EvenOddDoubleRecoveryFunc(RF_DagNode_
 	}
 	/*
 	      assign the beginning sector and the end sector for each parameter
-	      find out the corresponding colume # for each parameter
+	      find out the corresponding column # for each parameter
         */
 	for (prm = 0; prm < ndataParam; prm++) {
 		pda = node->params[prm].p;
@@ -859,7 +859,7 @@ rf_EOWriteDoubleRecoveryFunc(RF_DagNode_
 	/* determine the startSector and endSector for decoding */
 	startSector = rf_StripeUnitOffset(layoutPtr, fpda->startSector);
 	endSector = startSector + fpda->numSector;
 	/* Assign buf[col] pointers to point to each non-failed colume  and
 	 * initialize the pbuf and ebuf to point at the beginning of each
 	 * source buffers and destination buffers */
 	for (prm = 0; prm < numDataCol - 2; prm++) {
@@ -871,11 +871,11 @@ rf_EOWriteDoubleRecoveryFunc(RF_DagNode_
 	 * goes on */
 	pbuf = ppda->bufPtr;
 	ebuf = epda->bufPtr;
 	/* find out the logical colume numbers in the encoding matrix of the
 	 * two failed columes */
 	fcol[0] = rf_EUCol(layoutPtr, fpda->raidAddress);
 
 	/* find out the other failed colume not accessed this time */
 	sosAddr = rf_RaidAddressOfPrevStripeBoundary(layoutPtr, asmap->raidAddress);
 	for (i = 0; i < numDataCol; i++) {
 		npda.raidAddress = sosAddr + (i * secPerSU);
@@ -908,7 +908,7 @@ rf_EOWriteDoubleRecoveryFunc(RF_DagNode_
 	}
 	/* after recovery, the buffer pointed by olddata[0] is the old failed
 	 * data. With new writing data and this old data, use small write to
-	 * calculate the new redundant informations */
+	 * calculate the new redundant information */
 	/* node->params[ 0, ... PDAPerDisk * (numDataCol - 2)-1 ] are Pdas of
 	 * Rrd; params[ PDAPerDisk*(numDataCol - 2), ... PDAPerDisk*numDataCol
 	 * -1 ] are Pdas of Rp, ( Rp2 ), Re, ( Re2 ) ; params[
@@ -917,14 +917,14 @@ rf_EOWriteDoubleRecoveryFunc(RF_DagNode_
 	 * wudNodes; For current implementation, we assume the simplest case:
 	 * asmap->numStripeUnitsAccessed == 1 and asmap->numDataFailed == 1
 	 * ie. PDAPerDisk = 1 then node->params[numDataCol] must be the new
-	 * data to be writen to the failed disk. We first bxor the new data
+	 * data to be written to the failed disk. We first bxor the new data
 	 * into the old recovered data, then do the same things as small
 	 * write. */
 
 	rf_bxor(((RF_PhysDiskAddr_t *) node->params[numDataCol].p)->bufPtr, olddata[0], numbytes);
 	/* do new 'E' calculation  */
 	/* find out the corresponding colume in encoding matrix for write
 	 * colume to be encoded into redundant disk 'E' */
 	scol = rf_EUCol(layoutPtr, fpda->raidAddress);
 	/* olddata[0] now is source buffer pointer; epda->bufPtr is the dest
 	 * buffer pointer               */
@@ -168,8 +168,8 @@ rf_SimpleONEFunc(RF_DagNode_t *node)
 		/* bxor to buffer of readDataNodes */
 		retcode = rf_bxor(node->params[5].p, node->params[1].p, length);
-		/* find out the corresponding colume in encoding matrix for
-		 * write colume to be encoded into redundant disk 'E' */
+		/* find out the corresponding column in encoding matrix for
+		 * write column to be encoded into redundant disk 'E' */
 		scol = rf_EUCol(layoutPtr, pda->raidAddress);
 		srcbuf = node->params[1].p;
@@ -297,10 +297,10 @@ rf_e_EncOneSect(
 	int     numRowInEncMatix = (RF_EO_MATRIX_DIM) - 1;
 	RF_RowCol_t j, indexInDest,	/* row index of an encoding unit in
-					 * the destination colume of encoding
+					 * the destination column of encoding
 					 * matrix */
 	        indexInSrc;	/* row index of an encoding unit in the source
@@ -297,10 +297,10 @@ rf_e_EncOneSect(
 					 * matrix */
 	        indexInSrc;	/* row index of an encoding unit in the source
-				 * colume used for recovery */
+				 * column used for recovery */
 	int     bytesPerEU = bytesPerSector / numRowInEncMatix;
 
@@ -702,7 +702,7 @@ rf_EvenOddDoubleRecoveryFunc(RF_DagNode_
 		fcol[0] = rf_EUCol(layoutPtr, pda->raidAddress);
 
-		/* find out the other failed colume not accessed */
+		/* find out the other failed column not accessed */
 		sosAddr = rf_RaidAddressOfPrevStripeBoundary(layoutPtr, asmap->raidAddress);
 		for (i = 0; i < numDataCol; i++) {
@@ -720,7 +720,7 @@ rf_EvenOddDoubleRecoveryFunc(RF_DagNode_
 		pda1 = node->results[1];
 		memset(pda1->bufPtr, 0, bytesPerSector * pda1->numSector);
-		/* determine the failed colume numbers of the two failed
+		/* determine the failed column numbers of the two failed
 		 * disks. */
 		fcol[0] = rf_EUCol(layoutPtr, pda0->raidAddress);
@@ -859,7 +859,7 @@ rf_EOWriteDoubleRecoveryFunc(RF_DagNode_
 	startSector = rf_StripeUnitOffset(layoutPtr, fpda->startSector);
 	endSector = startSector + fpda->numSector;
-	/* Assign buf[col] pointers to point to each non-failed colume  and
+	/* Assign buf[col] pointers to point to each non-failed column  and
 	 * initialize the pbuf and ebuf to point at the beginning of each
 	 * source buffers and destination buffers */
@@ -871,11 +871,11 @@ rf_EOWriteDoubleRecoveryFunc(RF_DagNode_
 	pbuf = ppda->bufPtr;
 	ebuf = epda->bufPtr;
-	/* find out the logical colume numbers in the encoding matrix of the
-	 * two failed columes */
+	/* find out the logical column numbers in the encoding matrix of the
+	 * two failed columns */
 	fcol[0] = rf_EUCol(layoutPtr, fpda->raidAddress);
 
@@ -871,11 +871,11 @@ rf_EOWriteDoubleRecoveryFunc(RF_DagNode_
 	fcol[0] = rf_EUCol(layoutPtr, fpda->raidAddress);
 
-	/* find out the other failed colume not accessed this time */
+	/* find out the other failed column not accessed this time */
 	sosAddr = rf_RaidAddressOfPrevStripeBoundary(layoutPtr, asmap->raidAddress);
 	for (i = 0; i < numDataCol; i++) {
@@ -917,14 +917,14 @@ rf_EOWriteDoubleRecoveryFunc(RF_DagNode_
 	rf_bxor(((RF_PhysDiskAddr_t *) node->params[numDataCol].p)->bufPtr, olddata[0], numbytes);
 	/* do new 'E' calculation  */
-	/* find out the corresponding colume in encoding matrix for write
-	 * colume to be encoded into redundant disk 'E' */
+	/* find out the corresponding column in encoding matrix for write
+	 * column to be encoded into redundant disk 'E' */
 	scol = rf_EUCol(layoutPtr, fpda->raidAddress);
 	/* olddata[0] now is source buffer pointer; epda->bufPtr is the dest
